==> sign-center-api-0.3.16-sources.jar: cn/com/duiba/sign/center/api/dto/signrecord/SignRemindUserDto.java <==
package cn.com.duiba.sign.center.api.dto.signrecord;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by fangdong on 2019/08/29
 */
public class SignRemindUserDto implements Serializable {
    private static final long serialVersionUID = -366104747942938815L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 用户cid
     */
    private Long consumerId;

    /**
     * 用户uid
     */
    private String partnerUserId;

    /**
     * 签到活动类型，2-日历签到 4-养成签到 5-契约签到 6-经营签到 7-拉新签到 8-夺宝签到
     */
    private Integer signType;

    /**
     * 签到活动id
     */
    private Long signActivityId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Long getSignActivityId() {
        return signActivityId;
    }

    public void setSignActivityId(Long signActivityId) {
        this.signActivityId = signActivityId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> sign-center-api-0.3.42-20211222.034158-1-sources.jar: cn/com/duiba/sign/center/api/dto/signrecord/SignRemindUserDto.java <==
package cn.com.duiba.sign.center.api.dto.signrecord;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by fangdong on 2019/08/29
 */
public class SignRemindUserDto implements Serializable {
    private static final long serialVersionUID = -366104747942938815L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 用户cid
     */
    private Long consumerId;

    /**
     * 用户uid
     */
    private String partnerUserId;

    /**
     * 第三方平台用户id
     */
    private String openId;

    /**
     * 签到活动类型，2-日历签到 4-养成签到 5-契约签到 6-经营签到 7-拉新签到 8-夺宝签到
     */
    private Integer signType;

    /**
     * 签到活动id
     */
    private Long signActivityId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Long getSignActivityId() {
        return signActivityId;
    }

    public void setSignActivityId(Long signActivityId) {
        this.signActivityId = signActivityId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
